#!/bin/sh
#
# Licensed Materials - Property of IBM
# 5724-L62
#
# (C) Copyright IBM Corp. 2005  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# @(#)84   1.1.1.3   archiveagent/src/bin/aactl.sh, am_archiveagent, claret, 20050211010008 2/11/05 00:18:55
#
# (c) 2002-2004 Cyanea Systems Corp.
# All Rights Reserved
#

# Set environment variables.

if [ -z "$WSAMBIN" ]
then
	myDir=`dirname ${0}`
else
	myDir="$WSAMBIN"
fi

OS=`uname`
if [ "$OS" = "Windows" ]; then
	echo "This script can not run without a shell envirnment."
	echo "Aborting..."
	exit 50
elif [ "$OS" = "Interix" ]; then
	oldDir=`pwd`
	cd $myDir	
	. ./setenv.sh
else
	if [ -f ${myDir}/setenv.sh ]
	then
        	. ${myDir}/setenv.sh
	fi
fi

find_procs() 
{
  OS=`uname`
  case $OS in 
    Linux )
    PID_CMD="ps auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    AIX)
    PID_CMD="( export COLUMNS=5000 ; ps -eaf | grep '$1 start' | grep $2 | grep -v grep )";
  ;;
    SunOS )
    PID_CMD="/usr/ucb/ps -auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    Interix )
    PID_CMD="ps -eafwXunix | grep '$1 start' | grep $2 | grep -v grep";
  ;;
  esac

  FIND_PID=`eval ${PID_CMD} | awk '{ print $2 }'`
  export FIND_PID
}


CODEBASE_ADDRESS01=$KERNEL_HOST01:$PORT_KERNEL_CODEBASE01
CODEBASE_ADDRESS02=$KERNEL_HOST02:$PORT_KERNEL_CODEBASE02

COMMAND=$1

#if [ "$COMMAND" = "" ] ; then
#  COMMAND=ping
#fi

AA_PROPERTIES=$2
if [ "$AA_PROPERTIES" = "" ] ; then
  AA_PROPERTIES=aa1.properties
fi
if [ "$LOG_AA_PROPERTIES" = "" ] ; then
  LOG_AA_PROPERTIES=log-${AA_PROPERTIES}
fi

AA_NAME=`basename ${AA_PROPERTIES} .properties`
if [ "$AA_NAME" = "aa2" ] ; then
  AA_PORT=${PORT_ARCHIVE_AGENT2}
else
  AA_PORT=${PORT_ARCHIVE_AGENT1}
fi

case $COMMAND in
    start) 
        find_procs ArchiveAgentController ${AA_PROPERTIES}
        if [ "$FIND_PID" != "" ] ; then
            echo "Archive Agent has already been started on this machine for Property file ${AA_PROPERTIES}";
            exit 1;
        fi
        echo "starting archive agent..."

	if [ "$OS" = "Interix" ]; then
		CLASSPATH=${JDBC_DRIVER_JAR}
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\archiveagent.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\archiveagent-intf.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\cyaneaaux.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\model.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\j2ee.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\etc"
	else
        	CLASSPATH=.
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/archiveagent.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/archiveagent-intf.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/common.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/cyaneaaux.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/model.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/etc
        	CLASSPATH=${CLASSPATH}:${JDBC_DRIVER_JAR}
        	CLASSPATH=$CLASSPATH:${CYANEA_HOME}/lib/kernel.common.jar
        	CLASSPATH=$CLASSPATH:${CYANEA_HOME}/lib/j2ee.jar
	fi


# for archive agent properties, currently the code expects archiveagent.properties file
# to be resent in the classpath .
       
        SECURITY_POLICY_AA=${CYANEA_HOME_OS}/etc/aa.policy

        if [ "$HEAP_MIN_SIZE_ARCHIVE_AGENT" = "" ] ; then
	   HEAP_MIN_SIZE_ARCHIVE_AGENT=64
        fi
        if [ "$HEAP_MAX_SIZE_ARCHIVE_AGENT" = "" ] ; then
	   HEAP_MAX_SIZE_ARCHIVE_AGENT=64
        fi

        ${JAVA_HOME}/bin/$JAVA_CMD -classpath $CLASSPATH \
            -DJDBC_DRIVER_NAME=${JDBC_DRIVER_NAME} \
            -DDB_URL=${JDBC_DRIVER_URL} \
            -DDB_USER=${JDBC_USER} \
            -DDB_PASSWORD=${JDBC_PASSWORD} \
            -DserverPortNumber=${AA_PORT} \
            -Djava.security.policy=${SECURITY_POLICY_AA} \
            -Dkernel.codebase="http://$CODEBASE_ADDRESS01/kernel.core.jar http://$CODEBASE_ADDRESS02/kernel.core.jar" \
            -Dkernel.rfs.address="$KERNEL_HOST01:$PORT_KERNEL_RFS01 $KERNEL_HOST02:$PORT_KERNEL_RFS02" \
            -Djava.rmi.server.codebase="http://$CODEBASE_ADDRESS01/archiveagent-intf.jar http://$CODEBASE_ADDRESS02/archiveagent-intf.jar http://$CODEBASE_ADDRESS01/archiveagent.jar http://$CODEBASE_ADDRESS02/archiveagent.jar" \
            -Dcyanea.log.properties=${LOG_AA_PROPERTIES} \
            -Darchiveagent.propResource=${AA_PROPERTIES} \
            -Xms${HEAP_MIN_SIZE_ARCHIVE_AGENT}m \
            -Xmx${HEAP_MAX_SIZE_ARCHIVE_AGENT}m \
	    -Dcertificate.path=$CERT_PATH \
            -Dkeystore.location=$KEYSTR_LOC \
            -Dkeystore.storepass=$KEYSTR_PASS \
            -Dkeystore.keypass=$KEYSTR_KEYPASS \
            -Dnodeauth.userid=$NODE_USERID \
            -Dnodeauth.ip=$NODE_IP \
            com.cyanea.archiveagent.ArchiveAgentController $@  2>>$CYANEA_HOME/logs/am_stderr.log | tee -a $CYANEA_HOME/logs/am_stdout.log &
    	AACTL_PID=$!
    	if [ "$AACTL_PID_FILE" = "" ] ; then
      		AACTL_PID_FILE=/tmp/`basename ${AA_PROPERTIES} .properties`.pid
    	fi
    	echo $AACTL_PID > $AACTL_PID_FILE
    ;;
    dbtest) 
        echo "testing database connectionwith archiveagent properties...";
	if [ "$OS" = "Interix" ]; then
		CLASSPATH=${JDBC_DRIVER_JAR}
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\cyaneaaux.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\etc"
	else
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/common.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/cyaneaaux.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/kernel.common.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/etc
        	CLASSPATH=$CLASSPATH:${JDBC_DRIVER_JAR}
	fi
        ${JAVA_HOME}/bin/$JAVA_CMD -classpath $CLASSPATH \
            -DJDBC_DRIVER_NAME=${JDBC_DRIVER_NAME} \
            -DDB_URL=${JDBC_DRIVER_URL} \
            -DDB_USER=${JDBC_USER} \
            -DDB_PASSWORD=${JDBC_PASSWORD} \
            -Darchiveagent.propResource=${AA_PROPERTIES} \
            -Dcyanea.log.properties=${LOG_AA_PROPERTIES} \
            com.cyanea.common.dbtest.DBTest archiveagent $@; 
    ;;
    dumpcore)
     echo "dumping core... ";
     if [ "$AACTL_PID_FILE" = "" ] ; then
        AACTL_PID_FILE=/tmp/`basename ${AA_PROPERTIES} .properties`.pid
     fi
     AACTL_PID=`cat $AACTL_PID_FILE`
     echo "Dumping PID ${AACTL_PID}"
     kill -3 `cat $AACTL_PID_FILE`
   ;;
    stop | ping | status | fullstatus | debug | info | warn )
        echo "contacting archive agent";
	if [ "$OS" = "Interix" ]; then
		CLASSPATH=${JDBC_DRIVER_JAR}
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\archiveagent.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\archiveagent-intf.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\cyaneaaux.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\etc"
	else
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/archiveagent.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/archiveagent-intf.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/common.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/cyaneaaux.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/kernel.common.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/etc
	fi

        SECURITY_POLICY_AA=${CYANEA_HOME_OS}/etc/aa.policy

        ${JAVA_HOME}/bin/$JAVA_CMD -classpath $CLASSPATH \
            -DserverPortNumber=${AA_PORT} \
            -Djava.security.policy=${SECURITY_POLICY_AA} \
            -Dkernel.codebase="http://$CODEBASE_ADDRESS01/kernel.core.jar http://$CODEBASE_ADDRESS02/kernel.core.jar" \
            -Dkernel.rfs.address="$KERNEL_HOST01:$PORT_KERNEL_RFS01 $KERNEL_HOST02:$PORT_KERNEL_RFS02" \
            -Dcyanea.log.properties=${LOG_AA_PROPERTIES} \
            -Darchiveagent.propResource=${AA_PROPERTIES} \
	    -Dcertificate.path=$CERT_PATH \
            -Dkeystore.location=$KEYSTR_LOC \
            -Dkeystore.storepass=$KEYSTR_PASS \
            -Dkeystore.keypass=$KEYSTR_KEYPASS \
            -Dnodeauth.userid=$NODE_USERID \
            -Dnodeauth.ip=$NODE_IP \
            com.cyanea.archiveagent.ArchiveAgentController $@;
    ;;    
    killall | forcestop ) 
        find_procs ArchiveAgentController ArchiveAgentController
        echo "killing -9 all achive agent processes";
        if [ "$FIND_PID" = "" ] ; then
            echo "archive agent does not appear to be running, (no processes found)."
            exit 1;
        fi;
        kill -9  $FIND_PID;
    ;;
    *) 
        echo "usage: aactl ( start | stop | ping | status | fullstatus | dbtest | killall | dumpcore | debug | info | warn | help )";
        echo "  start      - start archive agent";
        echo "  stop       - stop archive agent";
        echo "  ping       - ping archive agent to see if it is alive";
        echo "  status     - retrieve archive agent server status";
        echo "  fullstatus - retrieve archive agent server and worker status";
        echo "  forcestop  - kill -9 all archive agent proccesses";
        echo "  dumpcore   - dump java core for the archiveagent proccess";
        echo "  dbtest     - test db connection";
        echo "  debug      - change log level to DEBUG";
        echo "  info       - change log level to INFO";
        echo "  warn       - change log level to WARN";
        echo "  help       - view this info";
    ;;
esac

if [ "$OS" = "Interix" ]; then
	cd $oldDir
fi
