#!/bin/sh
#
# Licensed Materials - Property of IBM
# 5724-L62
#
# (C) Copyright IBM Corp. 2005  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# @(#)10   1.1.1.3   kernel.core/src/bin/klctl.sh, am_kernel.core, claret, 20050211010008 2/11/05 00:18:57
#
# (c) 2002-2004 Cyanea Systems Corp.
# All Rights Reserved
#

# Set environment variables.
	
if [ -z "$WSAMBIN" ]
then
        myDir=`dirname ${0}`
else
        myDir="$WSAMBIN"
fi

myName=`basename ${0}`

OS=`uname`
if [ "$OS" = "Windows" ]; then
	echo "This script can not run without a shell envirnment."
	echo "Aborting..."
	exit 50
elif [ "$OS" = "Interix" ]; then
	oldDir=`pwd`
	cd $myDir	
	. ./setenv.sh
else
	if [ -f ${myDir}/setenv.sh ]
	then
        	. ${myDir}/setenv.sh
	fi
fi


find_procs() 
{
  OS=`uname`
  case $OS in 
    Linux )
    PID_CMD="ps auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    AIX)
    PID_CMD="( export COLUMNS=5000 ; ps -eaf | grep '$1 start' | grep $2 | grep -v grep )";
  ;;
    SunOS )
    PID_CMD="/usr/ucb/ps -auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    Interix )
    PID_CMD="ps -eafwXunix | grep '$1 start' | grep $2 | grep -v grep";
  ;;
  esac

  FIND_PID=`eval ${PID_CMD} | awk '{ print $2 }'`
  export FIND_PID
}


CODEBASE_ADDRESS01=$KERNEL_HOST01:$PORT_KERNEL_CODEBASE01
CODEBASE_ADDRESS02=$KERNEL_HOST02:$PORT_KERNEL_CODEBASE02

COMMAND=$1

KERNEL_PROPERTIES=$2
if [ "$KERNEL_PROPERTIES" = "" ] ; then
  KERNEL_PROPERTIES=kl1.properties
fi

KERNEL_LOG_PROPERTIES=log-${KERNEL_PROPERTIES}
KERNEL_NAME=`basename ${KERNEL_PROPERTIES} .properties`


if [ "$KERNEL_NAME" = "kl1" ] ; then
  KERNEL_HOST=${KERNEL_HOST01}
  PORT_KERNEL_RFS=${PORT_KERNEL_RFS01}
  PORT_KERNEL_CODEBASE=${PORT_KERNEL_CODEBASE01}
  PORT_KERNEL_RMI=${PORT_KERNEL_RMI01}
elif [ "$KERNEL_NAME" = "kl2" ] ; then
  KERNEL_HOST=${KERNEL_HOST02} 
  PORT_KERNEL_RFS=${PORT_KERNEL_RFS02} 
  PORT_KERNEL_CODEBASE=${PORT_KERNEL_CODEBASE02}
  PORT_KERNEL_RMI=${PORT_KERNEL_RMI02}
else  
  KERNEL_HOST=${KERNEL_HOST01}
  PORT_KERNEL_RFS=${PORT_KERNEL_RFS01}
  PORT_KERNEL_CODEBASE=${PORT_KERNEL_CODEBASE01}
  PORT_KERNEL_RMI=${PORT_KERNEL_RMI01}
fi

if [ "$HEAP_MIN_SIZE_KERNEL" = "" ] ; then
  HEAP_MIN_SIZE_KERNEL=16
fi
if [ "$HEAP_MAX_SIZE_KERNEL" = "" ] ; then
  HEAP_MAX_SIZE_KERNEL=32
fi


if [ "$OS" = "Interix" ]; then
	CLASSPATH=${JDBC_DRIVER_JAR}
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\cyaneaaux.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\common.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.core.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.common.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\model.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\etc"
else
	CLASSPATH=$CLASSPATH:${JDBC_DRIVER_JAR}
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/cyaneaaux.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/common.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/kernel.core.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/kernel.common.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/model.jar
	CLASSPATH=$CLASSPATH:/server/lib/weblogic.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/etc
fi

case $COMMAND in
    start ) 
	cd $myDir
        find_procs KernelManager ${KERNEL_PROPERTIES}
        if [ "$FIND_PID" != "" ] ; then
            echo "Kernel ${KERNEL_NAME} has already been started on this machine";
            exit 1;
        fi
	rm -rf "$CYANEA_HOME/logs/klstop.${KERNEL_NAME}"
	$JAVA_HOME/bin/$JAVA_CMD -Xms${HEAP_MIN_SIZE_KERNEL}m -Xmx${HEAP_MAX_SIZE_KERNEL}m -classpath $CLASSPATH \
                -Dkernel.codebase.libpath=${CYANEA_HOME_OS}/lib \
                -Dkernel.codebase.port=${PORT_KERNEL_CODEBASE} \
                -Dkernel.rmi.port=${PORT_KERNEL_RMI} \
                -Dkernel.rfs.port=${PORT_KERNEL_RFS} \
                -Djdbc.driver.name=${JDBC_DRIVER_NAME} \
                -Ddb.url=${JDBC_DRIVER_URL} \
                -Ddb.user=${JDBC_USER} \
                -Ddb.password=${JDBC_PASSWORD} \
	        -Djava.security.policy=$CYANEA_HOME_OS/etc/kl.policy \
		-Dcyanea.log.properties=${KERNEL_LOG_PROPERTIES} \
		-Dproperties.filename=${KERNEL_PROPERTIES} \
		-Dcertificate.path=$CERT_PATH \
		-Dkeystore.location=$KEYSTR_LOC \
		-Dkeystore.storepass=$KEYSTR_PASS \
		-Dkeystore.keypass=$KEYSTR_KEYPASS \
		-Dnodeauth.userid=$NODE_USERID \
		-Dnodeauth.ip=$NODE_IP \
	        com.cyanea.kernel.util.KernelManager start ${KERNEL_NAME}  2>>$CYANEA_HOME/logs/am_stderr.log | tee -a $CYANEA_HOME/logs/am_stdout.log &
    ;;
    stop | ping | status | warn | debug | info | getThreadProperties | setThreadProperties | getRFSCBSPoolProps | setRFSCBSPoolProps )
        echo "Contacting Kernel...";
	if [ "$COMMAND" = "stop" ] ; then
	   #echo "Creating stop file"
	   touch "$CYANEA_HOME/logs/klstop.${KERNEL_NAME}"
	fi

        $JAVA_HOME/bin/$JAVA_CMD -classpath $CLASSPATH \
            -Djava.security.policy=$CYANEA_HOME_OS/etc/kl.policy \
	    -Dcertificate.path=$CERT_PATH \
            -Dkeystore.location=$KEYSTR_LOC \
            -Dkeystore.storepass=$KEYSTR_PASS \
            -Dkeystore.keypass=$KEYSTR_KEYPASS \
            -Dnodeauth.userid=$NODE_USERID \
	    -Dnodeauth.ip=$NODE_IP \
            com.cyanea.kernel.util.KernelManager $COMMAND $KERNEL_HOST $PORT_KERNEL_RFS;
    ;;    
    dbtest ) 
        echo "Testing DB Connection with kernel properties...";
	$JAVA_HOME/bin/$JAVA_CMD  -classpath $CLASSPATH \
                -Djdbc.driver.name=${JDBC_DRIVER_NAME} \
                -Ddb.url=${JDBC_DRIVER_URL} \
                -Ddb.user=${JDBC_USER} \
                -Ddb.password=${JDBC_PASSWORD} \
		-Dproperties.filename=${KERNEL_PROPERTIES} \
		-Dcyanea.log.properties=${KERNEL_LOG_PROPERTIES} \
	        com.cyanea.common.dbtest.DBTest kernel; 
    ;;    
    importconfig )
        echo "Contacting Kernel...";
        $JAVA_HOME/bin/$JAVA_CMD -Xms${HEAP_MIN_SIZE_KERNEL}m -Xmx${HEAP_MAX_SIZE_KERNEL}m -classpath $CLASSPATH \
            -Djava.security.policy=$CYANEA_HOME_OS/etc/kl.policy \
            com.cyanea.kernel.util.KernelManager $1 $2 cyanea $KERNEL_HOST $PORT_KERNEL_RFS;
    ;;    
    exportconfig | removeconfig )
        echo "Contacting Kernel...";
        $JAVA_HOME/bin/$JAVA_CMD -Xms${HEAP_MIN_SIZE_KERNEL}m -Xmx${HEAP_MAX_SIZE_KERNEL}m -classpath $CLASSPATH \
            -Djava.security.policy=$CYANEA_HOME_OS/etc/kl.policy \
            com.cyanea.kernel.util.KernelManager $1 cyanea $KERNEL_HOST $PORT_KERNEL_RFS;
    ;;    
    forcestop )
        echo "killing -9 all Kernel processes";
        find_procs KernelManager KernelManager
        if [ "$FIND_PID" = "" ] ; then
            echo "Kernel does not appear to be running, (no processes found)."
            exit 1;
        fi;
        kill -9  $FIND_PID;
    ;;
    * ) 
        echo "${myName}: Usage: $myName ( start | stop | forcestop | dbtest | debug | warn | info | ping | status | getThreadProperties | setThreadProperties | getRFSCBSPoolProps | setRFSCBSPoolProps | help ) <properties resource> [filename]";
        echo "  start        - start Kernel";
        echo "  stop         - stop Kernel";
        echo "  forcestop    - forcestop Kernel";
        echo "  debug        - switch to debugging mode";
        echo "  warn         - switch to warning mode";
        echo "  info         - switch to informative mode";
        echo "  ping         - ping Kernel to see if it is alive";
        echo "  status       - retrieve Kernel status";
        echo "  dbtest       - test database connection";
        echo "  importconfig - importing configuration from a file. The syntax is 'klctl importconfig [filename]'";
        echo "  exportconfig - exporting configuration to a file";
        echo "  removeconfig - removing configuration from the repository";
        echo "  setThreadProperties - sets the ThreadPoolProperties of the RMI Object";
        echo "  getThreadProperties - gets the ThreadPoolProperties of the RMI Object";
        echo "  setRFSCBSPoolProps - sets the ThreadPoolProperties of the CodeBaseServer and RFSServer";
        echo "  getRFSCBSPoolProps - gets the ThreadPoolProperties of the CodeBaseServer and RFSServer";
        echo "  help         - view this info";
    ;;
esac

if [ "$OS" = "Interix" ]; then
	cd $oldDir
fi

