#!/bin/sh
#
# Licensed Materials - Property of IBM
# 5724-L62
#
# (C) Copyright IBM Corp. 2005  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# @(#)31   1.1.1.3   pollingagent/src/bin/pactl.sh, am_pollingagent, claret, 20050211010008 2/11/05 00:19:11
#
# (c) 2002-2004 Cyanea Systems Corp.
# All Rights Reserved
#

# Set environment variables.

if [ -z "$WSAMBIN" ]
then
        myDir=`dirname ${0}`
else
        myDir="$WSAMBIN"
fi

OS=`uname`
if [ "$OS" = "Windows" ]; then
	echo "This script can not run without a shell envirnment."
	echo "Aborting..."
	exit 50
elif [ "$OS" = "Interix" ]; then
	oldDir=`pwd`
	cd $myDir	
	. ./setenv.sh
else
	if [ -f ${myDir}/setenv.sh ]
	then
        	. ${myDir}/setenv.sh
	fi
fi

find_procs() 
{
  OS=`uname`
  case $OS in 
    Linux )
    PID_CMD="ps auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    AIX)
    PID_CMD="( export COLUMNS=5000 ; ps -eaf | grep '$1 start' | grep $2 | grep -v grep )";
  ;;
    SunOS )
    PID_CMD="/usr/ucb/ps -auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    Interix )
    PID_CMD="ps -eafwXunix | grep '$1 start' | grep $2 | grep -v grep";
  ;;
  esac

  FIND_PID=`eval ${PID_CMD} | awk '{ print $2 }'`
  export FIND_PID
}


CODEBASE_ADDRESS01=$KERNEL_HOST01:$PORT_KERNEL_CODEBASE01
CODEBASE_ADDRESS02=$KERNEL_HOST02:$PORT_KERNEL_CODEBASE02

COMMAND=$1

#if [ "$COMMAND" = "" ] ; then
#  COMMAND=ping
#fi

PA_PROPERTIES=$2
if [ "$PA_PROPERTIES" = "" ] ; then
  PA_PROPERTIES=pa.properties
fi
if [ "$LOG_PA_PROPERTIES" = "" ] ; then
  LOG_PA_PROPERTIES=log-pa.properties
fi

case $COMMAND in
    start) 
        find_procs PollingAgentController ${PA_PROPERTIES}
        if [ "$FIND_PID" != "" ] ; then
            echo "Polling Agent has already been started on this machine for Property file ${PA_PROPERTIES}";
            exit 1;
        fi
        echo "starting polling agent..."
	if [ "$OS" = "Interix" ]; then
		CLASSPATH=${JDBC_DRIVER_JAR}
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\archiveagent.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\archiveagent-intf.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\cyaneaaux.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\pollingagent.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\pollingagent-intf.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\model.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\etc"
	else
        	CLASSPATH=.
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/archiveagent.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/archiveagent-intf.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/common.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/cyaneaaux.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/model.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/pollingagent.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/pollingagent-intf.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/etc
        	CLASSPATH=${CLASSPATH}:${JDBC_DRIVER_JAR}
        	CLASSPATH=$CLASSPATH:${CYANEA_HOME}/lib/kernel.common.jar
		CLASSPATH=$CLASSPATH:/server/lib/weblogic.jar
	fi


# for polling agent properties, currently the code expects pollingagent.properties file
# to be resent in the classpath .
       
        SECURITY_POLICY_PA=${CYANEA_HOME_OS}/etc/pa.policy

        if [ "$HEAP_MIN_SIZE_POLLING_AGENT" = "" ] ; then
	   HEAP_MIN_SIZE_POLLING_AGENT=64
        fi
        if [ "$HEAP_MAX_SIZE_POLLING_AGENT" = "" ] ; then
	   HEAP_MAX_SIZE_POLLING_AGENT=64
        fi

	${JAVA_HOME}/bin/$JAVA_CMD -classpath $CLASSPATH \
            -DserverPortNumber=${PORT_PA} \
            -Djava.security.policy=${SECURITY_POLICY_PA} \
            -Dkernel.codebase="http://$CODEBASE_ADDRESS01/kernel.core.jar http://$CODEBASE_ADDRESS02/kernel.core.jar" \
            -Dkernel.rfs.address="$KERNEL_HOST01:$PORT_KERNEL_RFS01 $KERNEL_HOST02:$PORT_KERNEL_RFS02" \
            -Djava.rmi.server.codebase="http://$CODEBASE_ADDRESS01/pollingagent.jar http://$CODEBASE_ADDRESS01/pollingagent-intf.jar http://$CODEBASE_ADDRESS02/pollingagent.jar http://$CODEBASE_ADDRESS02/pollingagent-intf.jar http://$CODEBASE_ADDRESS01/archiveagent-intf.jar http://$CODEBASE_ADDRESS02/archiveagent-intf.jar http://$CODEBASE_ADDRESS01/archiveagent.jar http://$CODEBASE_ADDRESS02/archiveagent.jar" \
            -Dcyanea.log.properties=${LOG_PA_PROPERTIES} \
            -Dpollingagent.propResource=${PA_PROPERTIES} \
            -Xms${HEAP_MIN_SIZE_POLLING_AGENT}m \
            -Xmx${HEAP_MAX_SIZE_POLLING_AGENT}m \
	    -Dcertificate.path=$CERT_PATH \
            -Dkeystore.location=$KEYSTR_LOC \
            -Dkeystore.storepass=$KEYSTR_PASS \
            -Dkeystore.keypass=$KEYSTR_KEYPASS \
            -Dnodeauth.userid=$NODE_USERID \
            -Dnodeauth.ip=$NODE_IP \
            com.cyanea.pollingagent.PollingAgentController $@  2>>$CYANEA_HOME/logs/am_stderr.log | tee -a $CYANEA_HOME/logs/am_stdout.log &
    ;;
    stop | ping | status )
        echo "contacting polling agent";
	if [ "$OS" = "Interix" ]; then
		CLASSPATH=${JDBC_DRIVER_JAR}
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\archiveagent.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\archiveagent-intf.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\cyaneaaux.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\pollingagent.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\pollingagent-intf.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.common.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\model.jar"
		CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\etc"
	else
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/pollingagent.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/pollingagent-intf.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/archiveagent.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/archiveagent-intf.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/common.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/model.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/cyaneaaux.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/lib/kernel.common.jar
        	CLASSPATH=${CLASSPATH}:${CYANEA_HOME}/etc
	fi

        SECURITY_POLICY_PA=${CYANEA_HOME_OS}/etc/pa.policy

        ${JAVA_HOME}/bin/$JAVA_CMD -classpath $CLASSPATH \
            -DserverPortNumber=${PORT_PA} \
            -Djava.security.policy=${SECURITY_POLICY_PA} \
            -Dkernel.codebase="http://$CODEBASE_ADDRESS01/kernel.core.jar http://$CODEBASE_ADDRESS02/kernel.core.jar" \
            -Dkernel.rfs.address="$KERNEL_HOST01:$PORT_KERNEL_RFS01 $KERNEL_HOST02:$PORT_KERNEL_RFS02" \
	    -Dcertificate.path=$CERT_PATH \
            -Dkeystore.location=$KEYSTR_LOC \
            -Dkeystore.storepass=$KEYSTR_PASS \
            -Dkeystore.keypass=$KEYSTR_KEYPASS \
            -Dnodeauth.userid=$NODE_USERID \
            -Dnodeauth.ip=$NODE_IP \
            com.cyanea.pollingagent.PollingAgentController $@;
    ;;    
    killall | forcestop ) 
        find_procs PollingAgentController PollingAgentController
        echo "killing -9 all achive agent processes";
        if [ "$FIND_PID" = "" ] ; then
            echo "polling agent does not appear to be running, (no processes found)."
            exit 1;
        fi;
        kill -9  $FIND_PID;
    ;;
    *) 
        echo "usage: pactl ( start | stop | forcestop | killall )";
        echo "  start      - start polling agent";
        echo "  stop       - stop polling agent";
        echo "  forcestop  - kill -9 all polling agent proccesses";
        echo "  ping       - ping polling agent";
    ;;
esac

if [ "$OS" = "Interix" ]; then
	cd $oldDir
fi

