#!/bin/sh
#
# Licensed Materials - Property of IBM
# 5724-L62
#
# (C) Copyright IBM Corp. 2005  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# @(#)81   1.1.1.3   sam.gps/src/bin/samctl.sh, am_sam.gps, claret, 20050211010008 2/11/05 00:19:14
#
# (c) 2002-2004 Cyanea Systems Corp.
# All Rights Reserved
#

if [ -z "$WSAMBIN" ]
then
        myDir=`dirname ${0}`
else
        myDir="$WSAMBIN"
fi

OS=`uname`
if [ "$OS" = "Windows" ]; then
	echo "This script can not run without a shell envirnment."
	echo "Aborting..."
	exit 50
elif [ "$OS" = "Interix" ]; then
	oldDir=`pwd`
	cd $myDir	
	. ./setenv.sh
else
	if [ -f ${myDir}/setenv.sh ]
	then
        	. ${myDir}/setenv.sh
	fi
fi

find_procs() 
{
  OS=`uname`
  case $OS in 
    Linux )
    PID_CMD="ps auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    AIX)
    PID_CMD="( export COLUMNS=5000 ; ps -eaf | grep '$1 start' | grep $2 | grep -v grep )";
  ;;
    SunOS )
    PID_CMD="/usr/ucb/ps -auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    Interix )
    PID_CMD="ps -eafwXunix | grep '$1 start' | grep $2 | grep -v grep";
  ;;
  esac

  FIND_PID=`eval ${PID_CMD} | awk '{ print $2 }'`
  export FIND_PID
}

if [ "$OS" = "Interix" ]; then
	CLASSPATH=${JDBC_DRIVER_JAR}
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\cyaneaaux.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\common.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\sam.gps.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\ppe.probe-intf.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.common.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\model.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\etc"
else
	CLASSPATH=.
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/kernel.common.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/common.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/model.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/etc
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/sam.gps.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/cyaneaaux.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/ppe.probe-intf.jar
	CLASSPATH=$CLASSPATH:${JDBC_DRIVER_JAR}
fi

COMMAND=$1

#if [ "$COMMAND" = "" ] ; then
#   COMMAND=ping
#fi

### Process option command arguments
SAM_PROPERTIES=$2
if [ "$SAM_PROPERTIES" = "" ] ; then
   SAM_PROPERTIES=sam1.properties
fi

LOG_SAM_PROPERTIES=$3
if [ "$LOG_SAM_PROPERTIES" = "" ] ; then
   LOG_SAM_PROPERTIES=log-${SAM_PROPERTIES}
fi


DIRECT_ARGS="$3 $4"

SECURITY_POLICY=${CYANEA_HOME_OS}/etc/sam.policy
export SECURITY_POLICY

RMI_CODEBASE="http://${KERNEL_HOST01}:${PORT_KERNEL_CODEBASE01}/sam.gps.jar http://${KERNEL_HOST02}:${PORT_KERNEL_CODEBASE02}/sam.gps.jar"
export RMI_CODEBASE

KERNEL_CODEBASE="http://${KERNEL_HOST01}:${PORT_KERNEL_CODEBASE01}/kernel.core.jar http://${KERNEL_HOST01}:${PORT_KERNEL_CODEBASE02}/kernel.core.jar"
export KERNEL_CODEBASE

KERNEL_RFS_ADDRESS="${KERNEL_HOST01}:${PORT_KERNEL_RFS01} ${KERNEL_HOST02}:${PORT_KERNEL_RFS02}"
export KERNEL_RFS_ADDRESS

case $COMMAND in 
  start)
   find_procs SamCtl ${SAM_PROPERTIES}
   if [ "$FIND_PID" != "" ] ; then
            echo "SAM has already been started on this machine for property file ${SAM_PROPERTIES}";
            exit 1;
   fi
   echo "starting SAM..."
   if [ "$HEAP_MIN_SIZE_SAM" = "" ] ; then
     HEAP_MIN_SIZE_SAM=64
   fi
   if [ "$HEAP_MAX_SIZE_SAM" = "" ] ; then
     HEAP_MAX_SIZE_SAM=128
   fi
   $JAVA_HOME/bin/$JAVA_CMD -classpath $CLASSPATH \
	-DPORT_SAM=${PORT_SAM} \
        -DHOST_SAM=${HOST_SAM} \
        -DJDBC_DRIVER_NAME=${JDBC_DRIVER_NAME} \
        -DDB_URL=${JDBC_DRIVER_URL} \
        -DDB_USER=${JDBC_USER} \
        -DDB_PASSWORD=${JDBC_PASSWORD} \
        -Djava.rmi.server.codebase="${RMI_CODEBASE}" \
        -Djava.security.policy=${SECURITY_POLICY} \
        -Dkernel.codebase="${KERNEL_CODEBASE}" \
        -Dkernel.rfs.address="${KERNEL_RFS_ADDRESS}" \
        -Dsam.propResource=${SAM_PROPERTIES} \
        -Dcyanea.log.properties=${LOG_SAM_PROPERTIES} \
        -Xms${HEAP_MIN_SIZE_SAM}m \
        -Xmx${HEAP_MAX_SIZE_SAM}m \
	-Dcertificate.path=$CERT_PATH \
	-Dkeystore.location=$KEYSTR_LOC \
	-Dkeystore.storepass=$KEYSTR_PASS \
	-Dkeystore.keypass=$KEYSTR_KEYPASS \
	-Dnodeauth.userid=$NODE_USERID \
	-Dnodeauth.ip=$NODE_IP \
    com.cyanea.sam.gps.GpsServer start  2>>$CYANEA_HOME/logs/am_stderr.log | tee -a $CYANEA_HOME/logs/am_stdout.log &
    SAMCTL_PID=$!
    if [ "$SAMCTL_PID_FILE" = "" ] ; then
      SAMCTL_PID_FILE=/tmp/`basename ${SAM_PROPERTIES} .properties`.pid
    fi
    echo $SAMCTL_PID > $SAMCTL_PID_FILE
   ;;
   forcestop | killall ) 
        find_procs GpsServer GpsServer
        echo "killing -9 all SAM processes ${FIND_PID}";
        if [ "$FIND_PID" = "" ] ; then
            echo "SAM does not appear to be running, (no processes found)."
            exit 1;
        fi;
        kill -9  $FIND_PID;
    ;;
   dumpcore)
     if [ "$SAMCTL_PID_FILE" = "" ] ; then
        SAMCTL_PID_FILE=/tmp/`basename ${SAM_PROPERTIES} .properties`.pid
     fi
     SAMCTL_PID=`cat $SAMCTL_PID_FILE`
     echo "Dumping PID ${SAMCTL_PID}"
     kill -3 `cat $SAMCTL_PID_FILE`
   ;;
   stop)
     $JAVA_HOME/bin/$JAVA_CMD -classpath $CLASSPATH \
	-DPORT_SAM=${PORT_SAM} \
        -DHOST_SAM=${HOST_SAM} \
        -DJDBC_DRIVER_NAME=${JDBC_DRIVER_NAME} \
        -DDB_URL=${JDBC_DRIVER_URL} \
        -DDB_USER=${JDBC_USER} \
        -DDB_PASSWORD=${JDBC_PASSWORD} \
        -Djava.rmi.server.codebase="${RMI_CODEBASE}" \
        -Djava.security.policy=${SECURITY_POLICY} \
        -Dkernel.codebase="${KERNEL_CODEBASE}" \
        -Dkernel.rfs.address="${KERNEL_RFS_ADDRESS}" \
        -Dsam.propResource=${SAM_PROPERTIES} \
        -Dcyanea.log.properties=${LOG_SAM_PROPERTIES} \
      	-Dcertificate.path=$CERT_PATH \
       	-Dkeystore.location=$KEYSTR_LOC \
      	-Dkeystore.storepass=$KEYSTR_PASS \
      	-Dkeystore.keypass=$KEYSTR_KEYPASS \
      	-Dnodeauth.userid=$NODE_USERID \
      	-Dnodeauth.ip=$NODE_IP \
    com.cyanea.sam.gps.GpsServer ${COMMAND}  
   ;;
   ping | status | debug | info | warn | test)
    $JAVA_HOME/bin/$JAVA_CMD -classpath $CLASSPATH \
	-DPORT_SAM=${PORT_SAM} \
        -DHOST_SAM=${HOST_SAM} \
        -DJDBC_DRIVER_NAME=${JDBC_DRIVER_NAME} \
        -DDB_URL=${JDBC_DRIVER_URL} \
        -DDB_USER=${JDBC_USER} \
        -DDB_PASSWORD=${JDBC_PASSWORD} \
        -Djava.rmi.server.codebase="${RMI_CODEBASE}" \
        -Djava.security.policy=${SECURITY_POLICY} \
        -Dkernel.codebase="${KERNEL_CODEBASE}" \
        -Dkernel.rfs.address="${KERNEL_RFS_ADDRESS}" \
        -Dsam.propResource=${SAM_PROPERTIES} \
        -Dcyanea.log.properties=${LOG_SAM_PROPERTIES} \
    com.cyanea.sam.gps.GpsServer ${COMMAND}  ${DIRECT_ARGS}
   ;; 
   *)
     echo "usage: samctl ( start | stop | ping | status | fullstop | dumpcore | debug | info | warn )"
   ;;
esac

if [ "$OS" = "Interix" ]; then
	cd $oldDir
fi
