#!/bin/sh
#
# Licensed Materials - Property of IBM
# 5724-L62
#
# (C) Copyright IBM Corp. 2005  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# @(#)13   1.1.1.3   kernel.core/src/bin/wdctl.sh, am_kernel.core, claret, 20050211010008 2/11/05 00:19:08
#
# (c) 2002-2004 Cyanea Systems Corp.
# All Rights Reserved
#

# Set environment variables..

if [ -z "$WSAMBIN" ]
then
        myDir=`dirname ${0}`
else
        myDir="$WSAMBIN"
fi

myName=`basename ${0}`

OS=`uname`
if [ "$OS" = "Windows" ]; then
	echo "This script can not run without a shell envirnment."
	echo "Aborting..."
	exit 50
elif [ "$OS" = "Interix" ]; then
	oldDir=`pwd`
	cd $myDir	
	. ./setenv.sh
else
	if [ -f ${myDir}/setenv.sh ]
	then
        	. ${myDir}/setenv.sh
	fi
fi

find_procs() 
{
  OS=`uname`
  case $OS in 
    Linux )
    PID_CMD="ps auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    AIX)
    PID_CMD="( export COLUMNS=5000 ; ps -eaf | grep '$1 start' | grep $2 | grep -v grep )";
  ;;
    SunOS )
    PID_CMD="/usr/ucb/ps -auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    Interix )
    PID_CMD="ps -eafwXunix | grep '$1 start' | grep $2 | grep -v grep";
  ;;
  esac

  FIND_PID=`eval ${PID_CMD} | awk '{ print $2 }'`
  export FIND_PID
}


CODEBASE_ADDRESS01=$KERNEL_HOST01:$PORT_KERNEL_CODEBASE01
CODEBASE_ADDRESS02=$KERNEL_HOST02:$PORT_KERNEL_CODEBASE02

COMMAND=$1

KERNEL_PROPERTIES=$2
if [ "$KERNEL_PROPERTIES" = "" ] ; then
  KWD_PROPERTIES=wd1.properties
  KERNEL_PROPERTIES=kl1.properties
fi

KERNEL_LOG_PROPERTIES=log-${KERNEL_PROPERTIES}
KERNEL_NAME=`basename ${KERNEL_PROPERTIES} .properties`


if [ "$KERNEL_NAME" = "kl1" ] ; then
  KERNEL_HOST=${KERNEL_HOST01}
  PORT_KERNEL_RFS=${PORT_KERNEL_RFS01}
  PORT_KERNEL_CODEBASE=${PORT_KERNEL_CODEBASE01}
  PORT_KERNEL_RMI=${PORT_KERNEL_RMI01}
  KWD_PROPERTIES=klwd1.properties
elif [ "$KERNEL_NAME" = "kl2" ] ; then
  KERNEL_HOST=${KERNEL_HOST02} 
  PORT_KERNEL_RFS=${PORT_KERNEL_RFS02} 
  PORT_KERNEL_CODEBASE=${PORT_KERNEL_CODEBASE02}
  PORT_KERNEL_RMI=${PORT_KERNEL_RMI02}
  KWD_PROPERTIES=klwd2.properties
else  
  KERNEL_HOST=${KERNEL_HOST01}
  PORT_KERNEL_RFS=${PORT_KERNEL_RFS01}
  PORT_KERNEL_CODEBASE=${PORT_KERNEL_CODEBASE01}
  PORT_KERNEL_RMI=${PORT_KERNEL_RMI01}
  KWD_PROPERTIES=klwd1.properties
fi

if [ "$HEAP_MIN_SIZE_KERNEL" = "" ] ; then
  HEAP_MIN_SIZE_KERNEL=16
fi
if [ "$HEAP_MAX_SIZE_KERNEL" = "" ] ; then
  HEAP_MAX_SIZE_KERNEL=32
fi

if [ "$OS" = "Interix" ]; then
	CLASSPATH=${JDBC_DRIVER_JAR}
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\cyaneaaux.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\common.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.core.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\kernel.common.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\lib\\model.jar"
	CLASSPATH="$CLASSPATH;$CYANEA_HOME_OS\\etc"
else
	CLASSPATH=$CLASSPATH:${JDBC_DRIVER_JAR}
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/cyaneaaux.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/common.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/kernel.core.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/kernel.common.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/lib/model.jar
	CLASSPATH=$CLASSPATH:/server/lib/weblogic.jar
	CLASSPATH=$CLASSPATH:$CYANEA_HOME/etc
fi

case $COMMAND in
    start ) 
	cd $myDir
        find_procs KernelManager ${KERNEL_PROPERTIES}
        if [ "$FIND_PID" != "" ] ; then
            echo "Kernel ${KERNEL_NAME} has already been started on this machine exiting ";
            exit 1;
        fi
       	find_procs KernelWDRMIImpl ${KERNEL_NAME}
       	if [ "$FIND_PID" != "" ] ; then
	echo " Killing Kernel Watchdog for ${KERNEL_NAME} that has already been started on this machine "
	kill -9 $FIND_PID
	fi
	
	flag=true
        while $flag ;
	do
	    echo "Starting Kernel ${KERNEL_NAME}"
	    rm -rf "$CYANEA_HOME/logs/klstop.${KERNEL_NAME}"
	   $JAVA_HOME/bin/$JAVA_CMD -Xms${HEAP_MIN_SIZE_KERNEL}m -Xmx${HEAP_MAX_SIZE_KERNEL}m -classpath $CLASSPATH \
                -Dkernel.codebase.libpath=${CYANEA_HOME_OS}/lib \
                -Dkernel.codebase.port=${PORT_KERNEL_CODEBASE} \
                -Dkernel.rmi.port=${PORT_KERNEL_RMI} \
                -Dkernel.rfs.port=${PORT_KERNEL_RFS} \
                -Djdbc.driver.name=${JDBC_DRIVER_NAME} \
                -Ddb.url=${JDBC_DRIVER_URL} \
                -Ddb.user=${JDBC_USER} \
                -Ddb.password=${JDBC_PASSWORD} \
                -Djava.security.policy=$CYANEA_HOME_OS/etc/kl.policy \
                -Dcyanea.log.properties=${KERNEL_LOG_PROPERTIES} \
                -Dproperties.filename=${KERNEL_PROPERTIES} \
		-Dcertificate.path=$CERT_PATH \
                -Dkeystore.location=$KEYSTR_LOC \
                -Dkeystore.storepass=$KEYSTR_PASS \
                -Dkeystore.keypass=$KEYSTR_KEYPASS \
                -Dnodeauth.userid=$NODE_USERID \
                -Dnodeauth.ip=$NODE_IP \
                com.cyanea.kernel.util.KernelManager start ${KERNEL_NAME} &
	   
	   	OS=`uname -m`
  		case $OS in
    		s390 )
           		sleep 60
        		;;
    		s390x )
           		sleep 60
        		;;
        	* )
           		sleep 10
         		;;
        	esac
	   
	   sleep 40
	   
	   echo "Starting Watchdog for Kernel: ${KERNEL_NAME}"
	   $JAVA_HOME/bin/$JAVA_CMD -Xms32m -Xmx64m -classpath $CLASSPATH \
		-Dcyanea.home=$CYANEA_HOME_OS \
                -Dkernel.codebase.libpath=${CYANEA_HOME_OS}/lib \
                -Dkernel.codebase.port=${PORT_KERNEL_CODEBASE} \
                -Dkernel.rmi.port=${PORT_KERNEL_RMI} \
                -Dkernel.rfs.port=${PORT_KERNEL_RFS} \
                -Djdbc.driver.name=${JDBC_DRIVER_NAME} \
                -Ddb.url=${JDBC_DRIVER_URL} \
                -Ddb.user=${JDBC_USER} \
                -Ddb.password=${JDBC_PASSWORD} \
                -Djava.security.policy=$CYANEA_HOME_OS/etc/kl.policy \
                -Dcyanea.log.properties=${KERNEL_LOG_PROPERTIES} \
                -Dproperties.filename=${KWD_PROPERTIES} \
		-Dcertificate.path=$CERT_PATH \
                -Dkeystore.location=$KEYSTR_LOC \
                -Dkeystore.storepass=$KEYSTR_PASS \
                -Dkeystore.keypass=$KEYSTR_KEYPASS \
                -Dnodeauth.userid=$NODE_USERID \
                -Dnodeauth.ip=$NODE_IP \
                com.cyanea.kernel.watchdog.KernelWDRMIImpl start ${KERNEL_NAME}

          status=$?
	  if [ $status  = 0 ]
	  then
 		echo "Kernel ${KERNEL_NAME} was stoppped gracefully or Kernel could not be contacted by Watchdog"
		flag=false;
		# When Kernel Stub cannot be obtained by Watchdog
        	find_procs KernelManager ${KERNEL_NAME}
        	if [ "$FIND_PID" != "" ] ; then
			kill -9 $FIND_PID
		fi
	  elif [ 125 = $status ]
          then
	       echo "Invalid or missing license file"
               flag=false;
          else
		echo "Watch Dog exited with an exit code: $status"
        	find_procs KernelManager ${KERNEL_NAME}
        	if [ "$FIND_PID" != "" ] ; then
			kill -9 $FIND_PID
			sleep 30
		fi

                if [ -f $CYANEA_HOME/logs/klstop.${KERNEL_NAME} ] ; then
                  echo "Kernel ${KERNEL_NAME} was stopped gracefully"
                  flag=false;
                fi
	  fi   
        done

    ;;
    stop )
        echo "Contacting Kernel ${KERNEL_NAME}...";
	touch "$CYANEA_HOME/logs/klstop.${KERNEL_NAME}"
        $JAVA_HOME/bin/$JAVA_CMD -classpath $CLASSPATH \
            -Djava.security.policy=$CYANEA_HOME_OS/etc/kl.policy \
	    -Dcertificate.path=$CERT_PATH \
            -Dkeystore.location=$KEYSTR_LOC \
            -Dkeystore.storepass=$KEYSTR_PASS \
            -Dkeystore.keypass=$KEYSTR_KEYPASS \
            -Dnodeauth.userid=$NODE_USERID \
            -Dnodeauth.ip=$NODE_IP \
            com.cyanea.kernel.util.KernelManager $COMMAND $KERNEL_HOST $PORT_KERNEL_RFS & 

	echo "Waiting for Kernel ${KERNEL_NAME} Shutdown..........."
	sleep 20
       	find_procs KernelManager ${KERNEL_NAME}
       	if [ "$FIND_PID" != "" ] ; then
	echo "Killing all Kernel ${KERNEL_NAME} processes..........."
		kill -9 $FIND_PID
	fi

       	find_procs KernelWDRMIImpl ${KERNEL_NAME}
       	if [ "$FIND_PID" != "" ] ; then
	echo "Killing all Kernel Watchdog ${KERNEL_NAME} processes..........."
		kill -9 $FIND_PID
	fi

	find_procs wdctl.sh ${KERNEL_NAME}
       	if [ "$FIND_PID" != "" ] ; then
	echo "Killing all Kernel Watchdog ${KERNEL_NAME} processes..........."
		kill -9 $FIND_PID
	fi

	sleep 10
	rm -rf "$CYANEA_HOME/logs/klstop.${KERNEL_NAME}"
    ;;    
    forcestop )
        echo "killing -9 all Kernel processes & Watchdog processes";

        find_procs wdctl.sh wdctl
        if [ "$FIND_PID" != "" ] ; then
                kill -9 $FIND_PID
        fi

	find_procs KernelManager KernelManager
        if [ "$FIND_PID" != "" ] ; then
                kill -9 $FIND_PID
        fi

        find_procs KernelWDRMIImpl KernelWDRMIImpl
        if [ "$FIND_PID" != "" ] ; then
                kill -9 $FIND_PID
        fi

        rm -rf "$CYANEA_HOME/logs/klstop.${KERNEL_NAME}"
	
    ;;
    status )
       	find_procs KernelWDRMIImpl ${KERNEL_NAME}
        if [ "$FIND_PID" != "" ] ; then
               echo "Watchdog for Kernel ${KERNEL_NAME} running...." 
	else
               echo "Watchdog for Kernel ${KERNEL_NAME} stopped...." 
        fi


    ;;
    * ) 
        echo "${myName}: Usage: $myName < start | stop | forcestop|status > < kl1.properties | kl2.properties >";
        echo "  start        - start Kernel with Watchdog";
        echo "  stop         - stop Kernel and Watchdog";
        echo "  forcestop    - forcestop all Kernels and Watchdogs";
        echo "  status    - status of WatchDog processes";
    ;;
esac

if [ "$OS" = "Interix" ]; then
	cd $oldDir
fi
